@@ -1,44 +1,44 @@
-## ---- results="asis", echo=FALSE, message=FALSE--------------------------
+## ---- results="asis", echo=FALSE, message=FALSE-------------------------------
 # <!-- pkgdown --> 
-# <!-- jquery --><script src="jquery.min.js" crossorigin="anonymous"></script>
-myfile<-"jquery.min.js"
+# <!-- jquery --><script src="js/jquery.min.js" crossorigin="anonymous"></script>
+myfile<-"js/jquery.min.js"
 if(file.exists(myfile)){
 cat(paste0('<script src="',myfile,'" crossorigin="anonymous"></script> <!-- # -->'))
 }
-# <!-- clipboard.js --><script src="clipboard.min.js"  crossorigin="anonymous"></script>
-myfile<-"clipboard.min.js"
+# <!-- clipboard.js --><script src="js/clipboard.min.js"  crossorigin="anonymous"></script>
+myfile<-"js/clipboard.min.js"
 if(file.exists(myfile)){
 cat(paste0('<script src="',myfile,'"crossorigin="anonymous"></script>'))
 }
-# <!-- Font Awesome icons --><link rel="stylesheet" href="all.minMod.css"  crossorigin="anonymous">
-myfile<-"all.minMod.css"
+# <!-- Font Awesome icons --><link rel="stylesheet" href="css/all.minMod.css"  crossorigin="anonymous">
+myfile<-"css/all.minMod.css"
 if(file.exists(myfile)){
 cat(paste0('<link rel="stylesheet" href="',myfile,'"  crossorigin="anonymous">'))
 }
-# <!-- Bootstrap --><link rel="stylesheet" href="bootstrap.minO.css" crossorigin="anonymous">
-myfile<-"bootstrap.minO.css"
+# <!-- Bootstrap --><link rel="stylesheet" href="css/bootstrap.minO.css" crossorigin="anonymous">
+myfile<-"css/bootstrap.minO.css"
 if(file.exists(myfile)){
 cat(paste0('<link rel="stylesheet" href="',myfile,'"  crossorigin="anonymous">'))
 }
-# <!-- # <script src="bootstrap.min.js"  crossorigin="anonymous"></script> -->
-myfile<-"bootstrap.min.js"
+# <!-- # <script src="js/bootstrap.min.js"  crossorigin="anonymous"></script> -->
+myfile<-"js/bootstrap.min.js"
 if(file.exists(myfile)){
 cat(paste0('<script src="',myfile,'" crossorigin="anonymous"></script> <!-- # -->'))
 }
-myfile<-"pkgdown2.js"
+myfile<-"js/pkgdown2.js"
 if(file.exists(myfile)){
 cat(paste0('<script src="',myfile,'"></script> <!-- # -->'))
 }
 
-## ---- results="hide", message=FALSE, warning=FALSE, eval=TRUE------------
+## ---- results="hide", message=FALSE, warning=FALSE, eval=TRUE-----------------
 
 #load package
 library(idiogramFISH) 
 
-## ---- message=FALSE, echo=FALSE------------------------------------------
+## ---- message=FALSE, echo=FALSE-----------------------------------------------
 packageCheck<-all(unlist(invisible(lapply(c("ggtree","grid","ggpubr","phytools","treeio","plyr"), function(pkg) requireNamespace(pkg, quietly=TRUE)  ) ) ) )
 
-## ---- message=FALSE, eval=packageCheck-----------------------------------
+## ---- message=FALSE, eval=packageCheck----------------------------------------
 require(ggplot2)
 require(phytools)
 require(ggpubr)
@@ -56,21 +56,21 @@ iqtreephylo   <- read.newick(iqtreeFile) # phytools
 iqtreephyloUM <- force.ultrametric(iqtreephylo, method= "extend") # phytools
 
 
-## ---- message=FALSE, eval=packageCheck-----------------------------------
+## ---- message=FALSE, eval=packageCheck----------------------------------------
 ggtreeOf8 <- ggtree(iqtreephyloUM) + geom_tiplab(size=6)
 
-## ---- message=FALSE,eval=packageCheck------------------------------------
+## ---- message=FALSE,eval=packageCheck-----------------------------------------
 gbuil2      <-  ggplot_build(ggtreeOf8)       # get ggplot_built
 gtgbuild    <-  ggplot_gtable(gbuil2)         # get gtable from ggplot_built
 gtgbuild$layout$clip[gtgbuild$layout$name == "panel"] <- "off"                # modify gtable
 ggtreeOf8b   <- as_ggplot(gtgbuild)            # back to ggplot
 gtgbuildgg2 <- ggtreeOf8b +  theme(plot.margin = unit(c(1,9.5,3,1.5), "cm") ) # top right bottom left - modify margins
 
-## ---- message=FALSE,eval=packageCheck------------------------------------
+## ---- message=FALSE,eval=packageCheck-----------------------------------------
 ggtreeOf8TIPS<-ggtreeOf8$data[which(ggtreeOf8$data$isTip),]
 desiredOrder  <- rev(ggtreeOf8TIPS[order(ggtreeOf8TIPS$y),]$label)
 
-## ---- message=FALSE,eval=packageCheck------------------------------------
+## ---- message=FALSE,eval=packageCheck-----------------------------------------
 # make a vector without missing OTUs
 desiredFiltered <- intersect(desiredOrder,allChrSizeSample$OTU)
 
@@ -80,7 +80,7 @@ allChrSizeSample$OTU <- factor(allChrSizeSample$OTU, levels = desiredFiltered)
 # order
 allChrSizeSample     <- allChrSizeSample[order(allChrSizeSample$OTU),]
 
-## ---- message=FALSE,eval=packageCheck------------------------------------
+## ---- message=FALSE,eval=packageCheck-----------------------------------------
 # Establish position of OTUs before missing data OTUs
 matchres <- match(desiredOrder,desiredFiltered)
 matchres[is.na(matchres)] <- "R"
@@ -93,7 +93,7 @@ BeforeMissing             <- desiredFiltered[posOTUsBeforeMissing]
 # This is the amount of missing OTUs, spaces to add (ghost karyotypes)
 valuesOfMissRepsBefore    <- reps$lengths[which(reps$values=="R")]
 
-## ---- message=FALSE, comment=NA, results="hide",eval=packageCheck--------
+## ---- message=FALSE, comment=NA, results="hide",eval=packageCheck-------------
 # plot to png file
 png(file="firstplot.png" ,width=962,height=962 )
 
@@ -103,8 +103,8 @@ par(fig=c(0,.3,0,1)) # location of left ghost plot
 plot.new()           # ghost plot to the left
 par(fig=c(.3,1,0,1)) # location of right plot
 
-plotIdiograms(allChrSizeSample,                # data.frame of Chr. Sizes
-              allMarksSample,                  # d.f. of Marks (inc. cen. marks) 
+plotIdiograms(dfChrSize = allChrSizeSample,    # data.frame of Chr. Sizes
+              dfMarkPos = allMarksSample,      # d.f. of Marks (inc. cen. marks) 
               dfMarkColor =  mydfMaColor,      # d.f. of mark characteristics
               
               roundness = 4,                   # roundness of vertices
@@ -119,8 +119,8 @@ plotIdiograms(allChrSizeSample,                # data.frame of Chr. Sizes
               karHeiSpace = 6.5,               # karyotype vertical relative size with spacing
               
               nameChrIndexPos=4,               # move the name of chr. indexes to left
-              morpho=TRUE,                     # add chr. morphology
-              chrIndex = TRUE,                 # add chr. indices
+              morpho="both",                   # add chr. morphology
+              chrIndex = "both",               # add chr. indices
               karIndex = TRUE,                 # add karyotype indices
               
               markLabelSpacer = 0              # spaces from rightmost chr. to legend
@@ -146,20 +146,20 @@ print(gtgbuildgg2,newpage=F)
 # close png
 dev.off()
 
-## ---- results="asis", comment=NA, echo=FALSE-----------------------------
+## ---- results="asis", comment=NA, echo=FALSE----------------------------------
 if(packageCheck){
 # cat(paste0("![](",myt,")"))
 cat(paste0("![](firstplot.png)" ) )
 # cat(paste0("![](firstplot.svg)" ) )
 } else {
-cat(paste0("![](firstplot2.png)" ) )
-# img1_path <- "../man/figures/firstplot2.svg"
+cat(paste0("![](../man/figures/firstplot2.png)" ) )
+# img1_path <- "../man/firstplot2.svg"
 # if(file.exists(img1_path)) {
 # cat(paste0("<img src=",img1_path," width=\"100%\">") )
 # }
 }
 
-## ---- message=FALSE, eval=packageCheck-----------------------------------
+## ---- message=FALSE, eval=packageCheck----------------------------------------
 require(ggplot2)
 require(phytools)
 require(ggpubr)
@@ -177,12 +177,12 @@ revBayesPhylo   <- read.beast(revBayesFile) # ggtree or treeio
 revBayesPhyloUM <- force.ultrametric(revBayesPhylo@phylo, method= "extend") # phytools
 
 
-## ---- message=FALSE,eval=packageCheck------------------------------------
+## ---- message=FALSE,eval=packageCheck-----------------------------------------
 is_tip           <- revBayesPhyloUM$edge[,2] <= length(revBayesPhyloUM$tip.label)
 ordered_tips     <- revBayesPhyloUM$edge[is_tip, 2]
 desiredorderRevB <- rev(revBayesPhyloUM$tip.label[ordered_tips])
 
-## ---- message=FALSE,eval=packageCheck------------------------------------
+## ---- message=FALSE,eval=packageCheck-----------------------------------------
 allChrSizeSampleHolo <- allChrSizeSample
 allChrSizeSampleHolo <- allChrSizeSampleHolo[,c("OTU","chrName","longArmSize")]
 colnames(allChrSizeSampleHolo)[which(names(allChrSizeSampleHolo)=="longArmSize")]<-"chrSize"
@@ -193,7 +193,7 @@ allMarksSampleHolo   <- allMarksSampleHolo[c("OTU","chrName","markName","markDis
 colnames(allMarksSampleHolo)[which(names(allMarksSampleHolo)=="markDistCen")] <- "markPos"
 allMarksSampleHolo[which(allMarksSampleHolo$markName=="5S"),]$markSize <- .5
 
-## ---- message=FALSE,eval=packageCheck------------------------------------
+## ---- message=FALSE,eval=packageCheck-----------------------------------------
 # make a vector without missing OTUs
 desiredFiltered <- intersect(desiredorderRevB,allChrSizeSampleHolo$OTU)
 
@@ -203,7 +203,7 @@ allChrSizeSampleHolo$OTU <- factor(allChrSizeSampleHolo$OTU, levels = desiredFil
 # order
 allChrSizeSampleHolo <- allChrSizeSampleHolo[order(allChrSizeSampleHolo$OTU),]
 
-## ---- message=FALSE,eval=packageCheck------------------------------------
+## ---- message=FALSE,eval=packageCheck-----------------------------------------
 # Establish position of OTUs before missing data OTUs
 matchres <- match(desiredorderRevB,desiredFiltered)
 matchres[is.na(matchres)]   <- "R"
@@ -216,23 +216,23 @@ BeforeMissingPlot2          <- desiredFiltered[posOTUsBeforeMissing]
 # This is the amount of missing OTUs, spaces to add (ghost karyotypes)
 valuesOfMissRepsBeforePlot2 <- reps$lengths[which(reps$values=="R")]
 
-## ---- message=FALSE, comment=NA, results="hide",eval=packageCheck--------
+## ---- message=FALSE, comment=NA, results="hide",eval=packageCheck-------------
 # plot to png file
 png(file=paste0("secondplot.png" ),width=962,height=700)
 
 {
 par(omi=rep(0,4) , mar=c(0,0,0,0), mfrow=c(1,2))
-par(fig=c(0,.3,0,1)) 
+par(fig=c(0,.27,0,1)) 
 par(mar=c(2,0,2,0)) # b l t r
 
 plot(revBayesPhyloUM)
-par(fig=c(0.3,1,0,1), new=TRUE)
+par(fig=c(0.27,1,0,1), new=TRUE)
 par(mar=c(0,0,0,0)) # b l t r
 
 # Function plotIdiogramsHolo deprecated after ver. 1.5.1 
 
 plotIdiograms(allChrSizeSampleHolo,               # chr. size data.frame
-              allMarksSampleHolo,                 # data.frame of marks' positions
+              dfMarkPos = allMarksSampleHolo,     # data.frame of marks' positions
               dfMarkColor =  mydfMaColor,         # d.f. of mark characteristics
               
               roundness = 4,                      # vertices roundness
@@ -252,31 +252,33 @@ plotIdiograms(allChrSizeSampleHolo,               # chr. size data.frame
               ,rulerPos = - 1                     # position of ruler
               ,rulerNumberSize = .35              # font size of number of ruler
               ,rulerNumberPos = .4                # position of ruler number
-              ,ruler.tck=-.004
+              ,ruler.tck=-.004                    # tick of ruler size and orient.
 
-              ,ylimTopMod = 0                     # modify ylim of top
-              ,ylimBotMod = 0                     # modify ylim of bottom
+              ,ylimTopMod = -4                    # modify ylim of top
+              ,ylimBotMod = -4                    # modify ylim of bottom
+              ,xlimRightMod = 3                   # modify xlim right argument
               ,asp=1                              # y x aspect
+              
 )
 }
 
 # close png
 dev.off()
 
-## ---- results="asis", comment=NA, echo=FALSE-----------------------------
+## ---- results="asis", comment=NA, echo=FALSE----------------------------------
 if(packageCheck){
 # myt2<-normalizePath(myt2)
 # cat(paste0("![](",myt2,")"))
 cat(paste0("![](secondplot.png)" ) )
 } else {
-cat(paste0("![](secondplot2.png)" ) )
-# img1_path <- "../man/figures/secondplot2.svg"
+cat(paste0("![](../man/figures/secondplot2.png)" ) )
+# img1_path <- "../man/secondplot2.svg"
 # if(file.exists(img1_path)) {
 # cat(paste0("<img src=",img1_path," width=\"100%\">") )
 # }
 }
 
-## ---- message=FALSE,eval=packageCheck------------------------------------
+## ---- message=FALSE,eval=packageCheck-----------------------------------------
 
 # Select this OTU from the monocen.
 monosel<-c("Species_F","Species_C","Species_A")
@@ -298,7 +300,7 @@ mixChrSize <- plyr::rbind.fill(allChrSizeSampleSel,allChrSizeSampleHoloSel)
 # merge marks' d.fs
 mixMarks   <- plyr::rbind.fill(allMarksSampleSel,allMarksSampleHoloSel)
 
-## ---- message=FALSE,eval=packageCheck------------------------------------
+## ---- message=FALSE,eval=packageCheck-----------------------------------------
 # make a vector without missing OTUs
 desiredFiltered <- intersect(desiredorderRevB, mixChrSize$OTU)
 
@@ -320,7 +322,7 @@ BeforeMissingPlot2          <- desiredFiltered[posOTUsBeforeMissing]
 # This is the amount of missing OTUs, spaces to add (ghost karyotypes)
 valuesOfMissRepsBeforePlot2 <- reps$lengths[which(reps$values=="R")]
 
-## ---- message=FALSE, comment=NA, results="hide",eval=packageCheck--------
+## ---- message=FALSE, comment=NA, results="hide",eval=packageCheck-------------
 # plot to png file
 png(file=paste0("thirdplot.png" ),width=1100,height=1000)
 {
@@ -333,7 +335,7 @@ png(file=paste0("thirdplot.png" ),width=1100,height=1000)
   par(mar=c(0,0,0,0))
   
 plotIdiograms(mixChrSize,                         # chr. size data.frame
-              mixMarks,                           # data.frame of marks' positions (inc. cen. marks)
+              dfMarkPos = mixMarks,               # data.frame of marks' positions (inc. cen. marks)
               dfMarkColor = mydfMaColor,          # d.f. of mark characteristics
               
               origin="b",                         # position measured from bottom of chr.
@@ -345,6 +347,7 @@ plotIdiograms(mixChrSize,                         # chr. size data.frame
               
               karIndex = TRUE                     # add karyotype index
               ,indexIdTextSize=.4                 # font size of indices and chr. names
+              ,distTextChr=0.7                    # dist. among chr. and chr. name
               
               ,addMissingOTUAfter = BeforeMissingPlot2           # add ghost OTUs after these names
               ,missOTUspacings    = valuesOfMissRepsBeforePlot2  # how many ghosts, respectively
@@ -359,7 +362,7 @@ plotIdiograms(mixChrSize,                         # chr. size data.frame
               ,rulerPos = -1                      # position of ruler
               ,rulerNumberSize = .35              # font size of number of ruler
               ,rulerNumberPos = .4                # position of ruler number
-              ,ruler.tck=-.004
+              ,ruler.tck=-.004                    # ruler tick size and orient.
               ,asp = 1                            # y x aspect
               
 )
@@ -367,12 +370,12 @@ plotIdiograms(mixChrSize,                         # chr. size data.frame
 # close png
 dev.off()
 
-## ---- results="asis", comment=NA, echo=FALSE, eval=TRUE------------------
+## ---- results="asis", comment=NA, echo=FALSE, eval=TRUE-----------------------
 if(packageCheck){
 cat(paste0("![](thirdplot.png)" ) )
 } else {
-cat(paste0("![](thirdplot2.png)" ) )
-# img1_path <- "../man/figures/logo.svg"
+cat(paste0("![](../man/figures/thirdplot2.png)" ) )
+# img1_path <- "../man/logo.svg"
 # if(file.exists(img1_path)) {
 # cat(paste0("<img src=",img1_path," width=\"100%\">") )
 # }
